@@ -1,5 +1,6 @@
 from django import forms
 from django.forms.forms import NON_FIELD_ERRORS
+from form_utils.forms import BetterForm
 
 # Custom Exceptions
 class NavItemTypeError(Exception):
@@ -35,7 +36,7 @@ class ImageItem(HTMLItem):
         self.responsive = responsive
 
 
-class FormItem(forms.Form):
+class FormItem(BetterForm):
     type = 'form'
     action = ''
     method = 'POST'
@@ -43,6 +44,9 @@ class FormItem(forms.Form):
     def add_error(self, error):
         self._errors[NON_FIELD_ERRORS] = self.error_class([error])
 
+    class Meta:
+        fieldsets = []
+
 
 class DropdownItem(HTMLItem):
     def __init__(self, links, text):
